<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es">
<context>
    <name>LXQtQuickLaunch</name>
    <message>
        <location filename="../../../lxqtquicklaunch.cpp" line="214"/>
        <source>Drop Error</source>
        <translation>Error al soltar</translation>
    </message>
    <message>
        <location filename="../../../lxqtquicklaunch.cpp" line="215"/>
        <source>File/URL &apos;%1&apos; cannot be embedded into QuickLaunch for now</source>
        <translation>El archivo/URL &apos;%1&apos; no puede incrustarse de momento en QuickLaunch</translation>
    </message>
    <message>
        <location filename="../../../lxqtquicklaunch.cpp" line="321"/>
        <source>Drop application
icons here</source>
        <translation>Soltar iconos de
aplicaciones aquí</translation>
    </message>
</context>
<context>
    <name>QuickLaunchButton</name>
    <message>
        <location filename="../../../quicklaunchbutton.cpp" line="55"/>
        <source>Move left</source>
        <translation>Mover a la izquierda</translation>
    </message>
    <message>
        <location filename="../../../quicklaunchbutton.cpp" line="58"/>
        <source>Move right</source>
        <translation>Mover a la derecha</translation>
    </message>
    <message>
        <location filename="../../../quicklaunchbutton.cpp" line="62"/>
        <source>Remove from quicklaunch</source>
        <translation>Quitar del lanzador rápido</translation>
    </message>
</context>
</TS>
